<?php

/**
 * Get WPAjaxTestCase class
 */
require_once( DIR_TESTCASE . '/test_admin_includes_ajax_actions.php' );

/**
 * Admin ajax functions to be tested
 */
include_once( ABSPATH . 'wp-admin/includes/ajax-actions.php' );

/**
 * Testing ajax tag search functionality
 *
 * @package    WordPress
 * @subpackage Unit Tests
 * @since      3.4.0
 * @group      Ajax
 */
class TestAjaxTagSearch extends WPAjaxTestCase {

	/**
	 * Test as an admin
	 */
	public function test_post_tag() {

		// Become an administrator
		$this->_setRole( 'administrator' );

		// Set up a default request
		$_GET['tax'] = 'post_tag';
		$_GET['q']   = 'chat';

		// Make the request
		try {
			$this->_handleAjax( 'ajax-tag-search' );
		} catch ( WPAjaxDieContinueException $e ) {
			unset( $e );
		}
		
		// Ensure we found the right match
		$this->assertEquals( $this->_last_response, 'chattels' );
	}

	/**
	 * Test as a logged out user
	 */
	public function test_logged_out() {

		// Log out
		wp_logout();
		
		// Set up a default request
		$_GET['tax'] = 'post_tag';
		$_GET['q']   = 'chat';

		// Make the request
		$this->setExpectedException( 'WPAjaxDieStopException', '-1' );
		$this->_handleAjax( 'ajax-tag-search' );		
	}

	/**
	 * Test with an invalid taxonomy type
	 */
	public function test_invalid_tax() {

		// Become an administrator
		$this->_setRole( 'administrator' );

		// Set up a default request
		$_GET['tax'] = 'invalid-taxonomy';
		$_GET['q']   = 'chat';

		// Make the request
		$this->setExpectedException( 'WPAjaxDieStopException', '0' );
		$this->_handleAjax( 'ajax-tag-search' );		
	}
	
	/**
	 * Test as an unprivileged user
	 */
	public function test_unprivileged_user() {

		// Become an administrator
		$this->_setRole( 'subscriber' );

		// Set up a default request
		$_GET['tax'] = 'post_tag';
		$_GET['q']   = 'chat';

		// Make the request
		$this->setExpectedException( 'WPAjaxDieStopException', '-1' );
		$this->_handleAjax( 'ajax-tag-search' );		
	}

}
